pub struct ZipArchive<'a> {
pub parent_dir: &'a Path,
pub alt_parent_dir: Option<&'a Path>,
pub files: &'a [PathBuf],
pub output_path: &'a Path,
}Fields
parent_dir: &'a PathThe parent directory of the files to be archived. This is used to create the directory structure in the archive.
alt_parent_dir: Option<&'a Path>Alternative parent directory to be used in the archive. This is used to create the directory structure if the parent directory is not present.
files: &'a [PathBuf]The files to be archived.
output_path: &'a PathThe path to the output file.
Implementations
Sourceimpl<'a> ZipArchive<'a>
A zip archive writer.
Writes the files to a zip archive.
The files are written to the archive with the directory structure
relative to the parent directory.
If the parent directory is not present, the alternative parent directory
is used to create the directory structure.
impl<'a> ZipArchive<'a>
A zip archive writer. Writes the files to a zip archive. The files are written to the archive with the directory structure relative to the parent directory. If the parent directory is not present, the alternative parent directory is used to create the directory structure.